Hypo kafka bridge
=================

This rest api is used to ingest records into a kafka instance running inside a docker compose network.

The best way is to use the kafka bridge api. This api is a python wrapper that simplifies the use of this rest api.
